#include "shapes.inc"

//*****************************************************
//   SCENE CONTROL

#declare use_radiosity = 3;  // 0=no rad  1=low qual with save 2=hi qual with save 3=load values
#declare camera_num = 1;
#declare use_textures = 1;
#declare use_direct_sunlight=1;
#declare use_skylight=0;
#declare use_radsky=1;
#declare use_banjo=1;
#declare use_painting=1;
#declare use_area_light =1;
//*****************************************************

#include "banjo_textures.inc"

global_settings {
  max_trace_level 20
  assumed_gamma 1.0
 #if (use_radiosity)  
  ambient_light 0.0 
  #include "banjo_rad.inc"
 #end
}

#default{texture{finish{ambient 0}}}

#if (camera_num=1)  //on table
  #declare camera_loc=<0,-66,58.5>;
  #declare camera_tar=<-18,-10,48>;
  #declare camera_ang=50;
#end

#if (camera_num=2)  //detail of pot
  #declare camera_loc=<57.8,-86,58.5>;
  #declare camera_tar=<3,-10,33>;
  #declare camera_ang=7;
#end

#if (camera_num=3)  //detail of fifth string tuner
  #declare camera_loc=<-9.5,-21.1,60>;
  #declare camera_tar=<-1.18,-6.4,55.8>;
  #declare camera_ang=15;
#end

#if (camera_num=4)  //detail of head
  #declare camera_loc=<57.8,-86,58.5>;
  #declare camera_tar=<0,-2.7,64>;
  #declare camera_ang=4;
#end

#if (camera_num=5)  //other end of room
  #declare camera_loc=<0,-10,58.5>;
  #declare camera_tar=<0,(-15*12),100>;
  #declare camera_ang=80;
#end

#if (camera_num=6)  //detail of pot
  #declare camera_loc=<0,-86,58.5>;
  #declare camera_tar=<0,-10,35>;
  #declare camera_ang=16;
#end

#if (camera_num=7)  //from angle
  #declare camera_loc=<15,-66,58.5>;
  #declare camera_tar=<0,-10,48>;
  #declare camera_ang=50;
#end

camera {
        perspective
        location camera_loc
        sky <0,0,1>
	right -x*1.33
        look_at camera_tar
        angle camera_ang
}

#if (use_banjo=1)
  #include "banjo.inc"
  object {b_banjo
   rotate <75,0,0>
   translate <-18,-11.1505,37.3155>
  }
#end

#include "room.inc"
#include "picks.inc"
object {finger_pick rotate 130*z translate <-11,-12,30>}
object {finger_pick rotate 150*z translate <-12.5,-11.5,30>}
object {thumb_pick rotate -105*z translate <-14,-13.5,30>}

#declare sun_brightness=4.0;
#declare sun_alt=60;
#declare sun_azi=110;


#if (use_direct_sunlight=1)
light_source {
  <0,1,0>
  color rgb <1.0, 1.0, 0.9>*sun_brightness
  parallel
  point_at <0,0,0>    //sunlight
  scale 1000
  rotate <sun_alt,0,sun_azi>
  #if (use_area_light=1)
    area_light
      <8, 0, 0> <0, 0, 8> // lights spread out across this distance (x * z)
      4, 4                // total number of lights in grid (4x*4z = 16 lights)
    adaptive 0          // 0,1,2,3...
    jitter              // adds random softening of light
    circular            // make the shape of the light circular
    orient              // orient light
  #end
}
#end

#if (use_skylight=1)
  light_source {
    0
    color rgb 1
    spotlight radius 90 falloff 90 tightness 0 point_at -y
    #if (use_area_light)
    area_light 72*x, 120*z, 6, 12 jitter adaptive 1
    #end
   rotate 90*z
   translate <-54,-24,60>
  }
#end
                       
#declare sky_intensity=10;
#if (use_radsky=1)
  sky_sphere {
    pigment {
      gradient z
      pigment_map {
        [0.00 color rgb <215,255,255>/255 * sky_intensity]
        [0.50 color rgb <215,255,255>/255 * sky_intensity]
        [0.51 color rgb 0]
        [1.0 color rgb 0.7]
      }
    }
  }
#else
  sky_sphere { S_Cloud1 rotate <90,0,0> }
#end
